@@ -136,12 +136,10 @@ trimq <- function(x) {
   sub('^"(.*)"$', "\\1", x)
 }
 
-# Often we don't need to parse the whole json file, only extract a single
-# record, which is faster and less error prone.
-get_json_field <- function(text, field) {
-  m <- regexpr(paste0('"', field, '"\\s*:\\s*"(\\w+)"'), text, perl = TRUE)
+get_json_sha <- function(text) {
+  m <- regexpr(paste0('"sha"\\s*:\\s*"(\\w+)"'), text, perl = TRUE)
   if (all(m == -1)) {
-    return(NA_character_)
+    return(fromJSON(text)$sha %||% NA_character_)
   }
 
   start <- attr(m, "capture.start")
