@@ -391,9 +391,9 @@ test_that("upgradeable_packages works", {
   expect_equal(upgradable_packages(object, "always", TRUE),
                object)
 
-  # returns 0 row object if "never"
+  # returns only uninstalled packages if "never"
   expect_equal(upgradable_packages(object, "never", TRUE),
-               object[0, ])
+               object[which(object$package == "magrittr"), ])
 
   # returns full object if "ask" and not is_interactive
   expect_equal(upgradable_packages(object, "ask", is_interactive = FALSE, TRUE),
@@ -423,10 +423,10 @@ test_that("upgradeable_packages works", {
   expect_equal(upgradable_packages(object, "ask", TRUE, is_interactive = TRUE),
                object)
 
-  # None should be the 0 row object
+  # None should be only un-installed packages
   mockery::stub(upgradable_packages, "utils::select.list", function(...) "None")
   expect_equal(upgradable_packages(object, "ask", TRUE, is_interactive = TRUE),
-               object[0, ])
+               object[which(object$package == "magrittr"), ])
 
   # CRAN should be only the CRAN packages
   mockery::stub(upgradable_packages, "utils::select.list", function(...) "CRAN packages only")
@@ -440,7 +440,7 @@ test_that("upgradeable_packages works", {
   # empty vector should be the 0 row object (you get this when canceling the selection)
   mockery::stub(upgradable_packages, "utils::select.list", function(...) character(0))
   expect_equal(upgradable_packages(object, "ask", TRUE, is_interactive = TRUE),
-               object[0, ])
+               object[which(object$package == "magrittr"), ])
 
   # If only given current or ahead packages (which dotenv is), just return that
   expect_equal(upgradable_packages(object[object$package == "dotenv", ], "ask", TRUE, is_interactive = TRUE),
