@@ -51,6 +51,11 @@ test_that("download basic auth", {
     "base_download",
     function(url, ...) { print(url); 0 })
 
+  mockery::stub(
+    download,
+    "curl_download",
+    function(url, ...) { print(url); 0 })
+
   expect_output(
     download(
       tempfile(),
@@ -65,6 +70,7 @@ test_that("download fallback to curl, https", {
 
   skip_on_cran()
   skip_if_offline()
+  skip_if(is_standalone())
 
   mockery::stub(download, "get_r_version", "3.0.0")
   download(tmp <- tempfile(), "https://httpbin.org/ip")
@@ -75,6 +81,7 @@ test_that("download with curl, basic auth", {
 
   skip_on_cran()
   skip_if_offline()
+  skip_if(is_standalone())
 
   mockery::stub(download, "get_r_version", "3.0.0")
   download(
